import{d as s,a6 as m,z as n,W as e,c as l,g as c,f as u,b as f}from"./index-9299e1c1.js";import{I as h}from"./ItemsListing-9a3a53ae.js";import"./VCheckbox-75b4c12a.js";import"./eventbus-fb52ce0b.js";import"./VListItem-748fc7af.js";import"./VCheckboxBtn-ad9d405a.js";import"./VList-6d58de6a.js";import"./VCardText-7bb4efb6.js";import"./VCard-6d87d169.js";import"./VMenu-02b91385.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-50af6ebb.js";import"./Button-784539f4.js";import"./VSpacer-caa12be4.js";/* empty css              */import"./PanelviewItemCompact-c5d1faef.js";import"./VAlert-708f5408.js";import"./Container-ff473259.js";import"./Toolbar-eb89f7db.js";import"./VToolbar-2949cae0.js";import"./VTextField-9151d790.js";import"./VInfiniteScroll-dfad6ac1.js";import"./layout-0bba43de.js";import"./VVirtualScroll-1c00b40c.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:r}=m(),a=n(()=>!t.path||t.path=="root"?r("browse"):e("bp6")?r("browse")+" | "+t.path:e("bp3")?t.path:r("browse")),p=async function(o){return await f.browse(o.offset,o.limit,t.path)};return(o,d)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-paged-data":p,"sort-keys":["original","name","name_desc"],title:a.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline","no-server-side-sorting":!0},null,8,["title","path"])]))}});export{J as default};
